@@ -9,7 +9,7 @@ import subprocess
 from pathlib import Path
 from typing import Optional
 
-from phylum.ci import SCRIPT_NAME
+from connect.utils.terminal.markdown import render
 from phylum.ci.ci_base import CIBase
 
 
@@ -60,7 +60,7 @@ class CINone(CIBase):
         # Reference: https://git-scm.com/book/en/v2/Git-Internals-Git-Objects
         cmd = f"git hash-object {self.lockfile}".split()
         lockfile_hash_object = subprocess.run(cmd, check=True, text=True, capture_output=True).stdout.strip()
-        label = f"{SCRIPT_NAME}_{self.ci_platform_name}_{current_branch}_{lockfile_hash_object}"
+        label = f"{self.ci_platform_name}_{current_branch}_{lockfile_hash_object[:7]}"
         label = label.replace(" ", "-")
 
         return label
@@ -104,6 +104,4 @@ class CINone(CIBase):
 
     def post_output(self) -> None:
         """Post the output of the analysis in the means appropriate for the CI environment."""
-        # This is a bit of a placeholder for now. The output works in that it is human readable.
-        # However, it is more meant for display on the web, as HTML and rendered Markdown.
-        print(f" [+] Analysis output:\n{self.analysis_output}")
+        print(f" [+] Analysis output:\n{render(self.analysis_output)}")
